==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AUshrBinop.h <==
// public final class soot.jimple.parser.node.AUshrBinop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4ff143b5e877eae0 soot_jimple_parser_node_AUshrBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_AUshrBinop_H_
#define _JC_soot_jimple_parser_node_AUshrBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TUshr$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AUshrBinop$sub_refs	_jc_soot_jimple_parser_node_AUshrBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AUshrBinop$sub_nonrefs	_jc_soot_jimple_parser_node_AUshrBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AUshrBinop$refs	_jc_soot_jimple_parser_node_AUshrBinop$refs;
typedef struct _jc_soot_jimple_parser_node_AUshrBinop$nonrefs	_jc_soot_jimple_parser_node_AUshrBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AUshrBinop$object	_jc_soot_jimple_parser_node_AUshrBinop$object;

typedef const struct _jc_soot_jimple_parser_node_AUshrBinop$vmethods	_jc_soot_jimple_parser_node_AUshrBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AUshrBinop$vtable	_jc_soot_jimple_parser_node_AUshrBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_AUshrBinop$vtype	_jc_soot_jimple_parser_node_AUshrBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AUshrBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *);
extern void _jc_soot_jimple_parser_node_AUshrBinop$method$_init$f26142f104229c6e(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *, struct _jc_soot_jimple_parser_node_TUshr$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AUshrBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AUshrBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *);
extern struct _jc_soot_jimple_parser_node_TUshr$object *_jc_soot_jimple_parser_node_AUshrBinop$method$getUshr$d5de6bdf741818e5(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *);
extern void _jc_soot_jimple_parser_node_AUshrBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AUshrBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AUshrBinop$method$setUshr$1ddcb7a1114f6e7a(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *, struct _jc_soot_jimple_parser_node_TUshr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AUshrBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AUshrBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AUshrBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AUshrBinop$method_info$getUshr$d5de6bdf741818e5;
extern _jc_method _jc_soot_jimple_parser_node_AUshrBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AUshrBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AUshrBinop$method_info$setUshr$1ddcb7a1114f6e7a;
extern _jc_method _jc_soot_jimple_parser_node_AUshrBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AUshrBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *);
	struct _jc_soot_jimple_parser_node_TUshr$object	*(*getUshr$d5de6bdf741818e5)(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setUshr$1ddcb7a1114f6e7a)(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *, struct _jc_soot_jimple_parser_node_TUshr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AUshrBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_AUshrBinop$vmethods	soot_jimple_parser_node_AUshrBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_AUshrBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AUshrBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AUshrBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TUshr$object	*__5fushr__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AUshrBinop$refs {
    _jc_soot_jimple_parser_node_AUshrBinop$sub_refs	soot_jimple_parser_node_AUshrBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AUshrBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AUshrBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_AUshrBinop$sub_nonrefs	soot_jimple_parser_node_AUshrBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AUshrBinop$object {
	_jc_soot_jimple_parser_node_AUshrBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AUshrBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_AUshrBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AUshrBinop$vtype _jc_soot_jimple_parser_node_AUshrBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AUshrBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AUshrBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_AUshrBinop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AUshrBinop.h <==
// public final class soot.jimple.parser.node.AUshrBinop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4ff143b5e877eae0 soot_jimple_parser_node_AUshrBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_AUshrBinop_H_
#define _JC_soot_jimple_parser_node_AUshrBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TUshr$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AUshrBinop$sub_refs	_jc_soot_jimple_parser_node_AUshrBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AUshrBinop$sub_nonrefs	_jc_soot_jimple_parser_node_AUshrBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AUshrBinop$refs	_jc_soot_jimple_parser_node_AUshrBinop$refs;
typedef struct _jc_soot_jimple_parser_node_AUshrBinop$nonrefs	_jc_soot_jimple_parser_node_AUshrBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AUshrBinop$object	_jc_soot_jimple_parser_node_AUshrBinop$object;

typedef const struct _jc_soot_jimple_parser_node_AUshrBinop$vmethods	_jc_soot_jimple_parser_node_AUshrBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AUshrBinop$vtable	_jc_soot_jimple_parser_node_AUshrBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_AUshrBinop$vtype	_jc_soot_jimple_parser_node_AUshrBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AUshrBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AUshrBinop$method$_init$f26142f104229c6e(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *, struct _jc_soot_jimple_parser_node_TUshr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AUshrBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AUshrBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TUshr$object *_jc_soot_jimple_parser_node_AUshrBinop$method$getUshr$d5de6bdf741818e5(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AUshrBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AUshrBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AUshrBinop$method$setUshr$1ddcb7a1114f6e7a(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *, struct _jc_soot_jimple_parser_node_TUshr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AUshrBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AUshrBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AUshrBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AUshrBinop$method_info$getUshr$d5de6bdf741818e5;
extern _jc_method _jc_soot_jimple_parser_node_AUshrBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AUshrBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AUshrBinop$method_info$setUshr$1ddcb7a1114f6e7a;
extern _jc_method _jc_soot_jimple_parser_node_AUshrBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AUshrBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TUshr$object	*(*getUshr$d5de6bdf741818e5)(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setUshr$1ddcb7a1114f6e7a)(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *, struct _jc_soot_jimple_parser_node_TUshr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AUshrBinop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AUshrBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_AUshrBinop$vmethods	soot_jimple_parser_node_AUshrBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_AUshrBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AUshrBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AUshrBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TUshr$object	*__5fushr__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AUshrBinop$refs {
    _jc_soot_jimple_parser_node_AUshrBinop$sub_refs	soot_jimple_parser_node_AUshrBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AUshrBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AUshrBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_AUshrBinop$sub_nonrefs	soot_jimple_parser_node_AUshrBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AUshrBinop$object {
	_jc_soot_jimple_parser_node_AUshrBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AUshrBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_AUshrBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AUshrBinop$vtype _jc_soot_jimple_parser_node_AUshrBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AUshrBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AUshrBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_AUshrBinop_H_ */
